package com.example.sampleproject;

import java.io.File;
import java.util.List;

import jp.co.nsw.baassdk.Content;
import jp.co.nsw.baassdk.GetContentDataDirCallback;
import jp.co.nsw.baassdk.GetContentsCallback;
import jp.co.nsw.baassdk.GetContentsFilter;
import jp.co.nsw.baassdk.NswBaaSManager;
import android.app.Activity;
import android.content.ComponentName;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

public class MainActivity extends Activity {

	private NswBaaSManager mManager = null;
	private Button mButtonContent = null;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		// NswBaaSManagerインスタンスの取得
        mManager = NswBaaSManager.getInstanse(getApplicationContext());
        
        // 初期化を実行
        mManager.init("[Google Developers Consoleで取得したProject Numberを指定する]", "[ポスモバWebで発行されたSDK IDを指定する]", new RegisterCallback() {
            @Override
            public void onSuccessRegister() {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        mButtonContent.setEnabled(true);
                    }
                });
            }
            
            @Override
            public void onFailRegister(final int reason) {
				//クライアント登録に失敗した場合本コールバックが呼ばれる。
				//自動でリトライするため、登録が成功した段階でonSuccessRegister()がコールされる。
            }
        });
        
        // SDKのパーミッションを指定。以下の指定では、「Push通知を受信する」「位置情報検索を使用する」。
        mManager.setPermission(true, true);
        
        // 通知領域に表示されるアイコンの指定
        //mManager.setNotificationSmallIconID(R.drawable.small);
        //mManager.setNotificationLargeIconID(R.drawable.large);
        
        // Push受信時のサウンドの指定
        mManager.setNotificationSoundUri(android.provider.Settings.System.DEFAULT_NOTIFICATION_URI);
        
        // ダイアログから起動するIntentを指定
        Intent intent = new Intent();
        ComponentName comp = new ComponentName(getPackageName(), MainActivity3.class.getName());
        intent.setComponent(comp);
        intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        mManager.setDefaultStartIntent(intent);
        
        
        // コンテンツの取得
        mButtonContent = (Button)findViewById(R.id.content);
        mButtonContent.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
				getContents();
            }
        });

		if(mManager.isRegistered()){
			mButtonContent.setEnabled(true);
		} else {
			mButtonContent.setEnabled(false);
		}
	}
	
    @Override
    protected void onPause() {
        super.onPause();
        // pause()をコールする
        mManager.pause();
    }

    @Override
    protected void onResume() {
        super.onResume();
        // resume()をコールする
        mManager.resume();
    }

	private void getContents(){
        GetContentsFilter gcf = new GetContentsFilter();
        // フィルターに「クーポンのみ」を指定
        gcf.setContentType(GetContentsFilter.TYPE_COUPON);
        mManager.getContentsRequest(gcf, new GetContentsCallback() {
            @Override
            public void onLocalContentsCallback(GetContentsFilter request, List<Content> contents) {
                Log.v("CONTENT", "onLocalContentsCallback");
                if(contents != null){
                    for (Content content : contents) {
                        Log.v("CONTENT", "Content:" + content);
                        // 付加データファイルURLがある場合は展開後フォルダを取得
                        if(!TextUtils.isEmpty(content.main.fileUrl)){
                            mManager.getContentDataDir(content.id, new GetContentDataDirCallback() {
                                @Override
                                public void onContentDataDirCallback(File dir) {
                                    Log.v("CONTENT", "onContentDataDirCallback:" + dir);
                                }
                            });
                        }
                    }
                }
            }
            
            @Override
            public void onDataUpdateNone(GetContentsFilter request) {
                Log.v("CONTENT", "onDataUpdateNone");
            }
            
            @Override
            public void onDataUpdateExist(GetContentsFilter request) {
                Log.v("CONTENT", "onDataUpdateExist");
            }
        });
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

}
