package com.example.sampleproject;

import jp.co.nsw.baassdk.Beacon;
import jp.co.nsw.baassdk.BeaconManager;
import jp.co.nsw.baassdk.BeaconManager.RangingCallback;
import jp.co.nsw.baassdk.BeaconManager.TransitionCallback;
import jp.co.nsw.baassdk.Content;
import jp.co.nsw.baassdk.NswBaaSManager;
import android.app.Activity;
import android.content.ComponentName;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;

public class MainActivity extends Activity {

	private NswBaaSManager mManager = null;
	private BeaconManager mBeacon = null;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		// NswBaaSManagerインスタンスの取得
        mManager = NswBaaSManager.getInstanse(getApplicationContext());
        
        // 初期化を実行
        mManager.init("[Google Developers Consoleで取得したProject Numberを指定する]", "[ポスモバWebで発行されたSDK IDを指定する]", new RegisterCallback() {
            @Override
            public void onSuccessRegister() {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        startBeacon();
                    }
                });
            }
            
            @Override
            public void onFailRegister(final int reason) {
				//クライアント登録に失敗した場合本コールバックが呼ばれる。
				//自動でリトライするため、登録が成功した段階でonSuccessRegister()がコールされる。
            }
        });
        
        // SDKのパーミッションを指定。以下の指定では、「Push通知を受信する」「位置情報検索を使用する」。
        mManager.setPermission(true, true);
        
        // 通知領域に表示されるアイコンの指定
        //mManager.setNotificationSmallIconID(R.drawable.small);
        //mManager.setNotificationLargeIconID(R.drawable.large);
        
        // Push受信時のサウンドの指定
        mManager.setNotificationSoundUri(android.provider.Settings.System.DEFAULT_NOTIFICATION_URI);
        
        // ダイアログから起動するIntentを指定
        Intent intent = new Intent();
        ComponentName comp = new ComponentName(getPackageName(), MainActivity2.class.getName());
        intent.setComponent(comp);
        intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        mManager.setDefaultStartIntent(intent);
	}
	
    @Override
    protected void onPause() {
        super.onPause();
        // pause()をコールする
        mManager.pause();
        
        if(mBeacon != null){
            mBeacon.stopBeaconSearch();
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        // resume()をコールする
        mManager.resume();

		startBeacon();
    }

	private void startBeacon(){
        // クライアント登録済みの場合、ビーコン検出動作を開始。
		if(mManager.isRegistered()){
	        mBeacon = mManager.getBeaconManager();
	        // Android4.3より前のOSバージョンの場合、getBeaconManager()の戻り値がnullとなる(ビーコン利用不可)
	        if(mBeacon != null){
	            int ret = mBeacon.startBeaconSearch();
	            if(ret == BeaconManager.START_SUCCESS){
	                mBeacon.setTransitionCallback(new TransitionCallback() {
	                    @Override
	                    public void onTransitionExit(final Beacon beacon) {
	                        // ビーコン検出範囲から出た
	                        Log.v("BEACON", "onTransitionExit: " + beacon);
	                        
	                    }
	                    
	                    @Override
	                    public void onTransitionEnter(final Beacon beacon) {
	                        // ビーコン検出範囲に入った
	                        Log.v("BEACON", "onTransitionEnter: " + beacon);
	                        
	                    }
	                    
	                    @Override
	                    public void onContentFound(final Beacon beacon, Content content) {
	                        // 検出したビーコンに関連したコンテンツが見つかった
	                        Log.v("BEACON", "onContentFound: " + beacon + " content: " + content);
	                        
	                    }
	                });
	                mBeacon.setRangingCallback(new RangingCallback() {
	                    @Override
	                    public void onRangeBeacon(final Beacon beacon) {
	                        // 検出中のビーコンの距離計測
	                        Log.v("BEACON", "onRangeBeacon: " + beacon);
	                        // ※距離はおおよその目安です。電波状況や遮蔽物の影響により正確度が変化します。
	                        Log.v("BEACON", "distance=" + beacon.distance + "[m]");
	                    }
	                });
	            }
	        }
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

}
